validate_google_subscription

Function validate_google_subscription 

pub fn validate_google_subscription(
    response: &GoogleResponse,
    now: DateTime<Utc>,
) -> Result<PurchaseResponse>
Simply validates based on whether or not the subscription’s expiration has passed.

Errors

Will return an error if the expiry_time in the response cannot be parsed as an i64