pub fn validate_google_subscription(
response: &GoogleResponse,
now: DateTime<Utc>,
) -> Result<PurchaseResponse>Expand description
Simply validates based on whether or not the subscription’s expiration has passed.
Errors
Will return an error if the expiry_time in the response cannot be parsed as an i64